@@ -50,7 +50,7 @@ class MS_Kile_Client_Principal_Lookup_Tests(KDCBaseTest):
         self.do_asn1_print = global_asn1_print
         self.do_hexdump = global_hexdump
 
-    def check_pac(self, samdb, auth_data, uc, name, upn=None):
+    def check_pac(self, auth_data, uc, name, upn=None):
 
         pac_data = self.get_pac_data(auth_data)
         if upn is None:
@@ -134,7 +134,7 @@ class MS_Kile_Client_Principal_Lookup_Tests(KDCBaseTest):
         # Check the contents of the pac, and the ticket
         ticket = rep['ticket']
         enc_part = self.decode_service_ticket(mc, ticket)
-        self.check_pac(samdb, enc_part['authorization-data'], uc, user_name)
+        self.check_pac(enc_part['authorization-data'], uc, user_name)
         # check the crealm and cname
         cname = enc_part['cname']
         self.assertEqual(NT_PRINCIPAL, cname['name-type'])
@@ -192,7 +192,7 @@ class MS_Kile_Client_Principal_Lookup_Tests(KDCBaseTest):
         # Check the contents of the pac, and the ticket
         ticket = rep['ticket']
         enc_part = self.decode_service_ticket(mc, ticket)
-        self.check_pac(samdb, enc_part['authorization-data'], mc, mach_name + '$')
+        self.check_pac(enc_part['authorization-data'], mc, mach_name + '$')
         # check the crealm and cname
         cname = enc_part['cname']
         self.assertEqual(NT_PRINCIPAL, cname['name-type'])
@@ -256,7 +256,7 @@ class MS_Kile_Client_Principal_Lookup_Tests(KDCBaseTest):
         # Check the contents of the service ticket
         ticket = rep['ticket']
         enc_part = self.decode_service_ticket(mc, ticket)
-        self.check_pac(samdb, enc_part['authorization-data'], uc, upn_name)
+        self.check_pac(enc_part['authorization-data'], uc, upn_name)
         # check the crealm and cname
         cname = enc_part['cname']
         self.assertEqual(NT_PRINCIPAL, cname['name-type'])
@@ -387,8 +387,7 @@ class MS_Kile_Client_Principal_Lookup_Tests(KDCBaseTest):
         # Check the contents of the pac, and the ticket
         ticket = rep['ticket']
         enc_part = self.decode_service_ticket(mc, ticket)
-        self.check_pac(samdb,
-                       enc_part['authorization-data'], uc, user_name)
+        self.check_pac(enc_part['authorization-data'], uc, user_name)
         # check the crealm and cname
         cname = enc_part['cname']
         self.assertEqual(NT_PRINCIPAL, cname['name-type'])
@@ -403,7 +402,7 @@ class MS_Kile_Client_Principal_Lookup_Tests(KDCBaseTest):
             This test uses the altsecid, so the AS-REQ should fail.
         """
 
-        # Create user and machine accounts for the test.
+        # Create a user account for the test.
         #
         samdb = self.get_samdb()
         user_name = "mskileusr"
@@ -413,10 +412,6 @@ class MS_Kile_Client_Principal_Lookup_Tests(KDCBaseTest):
         alt_sec = "Kerberos:%s@%s" % (alt_name, realm)
         self.add_attribute(samdb, dn, "altSecurityIdentities", alt_sec)
 
-        mach_name = "mskilemac"
-        (mc, _) = self.create_account(samdb, mach_name,
-                                      account_type=self.AccountType.COMPUTER)
-
         # Do the initial AS-REQ, should get a pre-authentication required
         # response
         etype = (AES256_CTS_HMAC_SHA1_96, ARCFOUR_HMAC_MD5)
@@ -492,8 +487,7 @@ class MS_Kile_Client_Principal_Lookup_Tests(KDCBaseTest):
         # Check the contents of the pac, and the ticket
         ticket = rep['ticket']
         enc_part = self.decode_service_ticket(mc, ticket)
-        self.check_pac(
-            samdb, enc_part['authorization-data'], uc, upn, upn=upn)
+        self.check_pac(enc_part['authorization-data'], uc, upn, upn=upn)
         # check the crealm and cname
         cname = enc_part['cname']
         crealm = enc_part['crealm']
@@ -557,8 +551,7 @@ class MS_Kile_Client_Principal_Lookup_Tests(KDCBaseTest):
         # Check the contents of the pac, and the ticket
         ticket = rep['ticket']
         enc_part = self.decode_service_ticket(mc, ticket)
-        self.check_pac(
-            samdb, enc_part['authorization-data'], uc, ename, upn=ename)
+        self.check_pac(enc_part['authorization-data'], uc, ename, upn=ename)
         # check the crealm and cname
         cname = enc_part['cname']
         crealm = enc_part['crealm']
@@ -623,8 +616,7 @@ class MS_Kile_Client_Principal_Lookup_Tests(KDCBaseTest):
         # Check the contents of the pac, and the ticket
         ticket = rep['ticket']
         enc_part = self.decode_service_ticket(mc, ticket)
-        self.check_pac(
-            samdb, enc_part['authorization-data'], mc, ename, upn=uname)
+        self.check_pac(enc_part['authorization-data'], mc, ename, upn=uname)
         # check the crealm and cname
         cname = enc_part['cname']
         crealm = enc_part['crealm']
@@ -759,8 +751,7 @@ class MS_Kile_Client_Principal_Lookup_Tests(KDCBaseTest):
         # Check the contents of the pac, and the ticket
         ticket = rep['ticket']
         enc_part = self.decode_service_ticket(mc, ticket)
-        self.check_pac(
-            samdb, enc_part['authorization-data'], uc, uname, upn=uname)
+        self.check_pac(enc_part['authorization-data'], uc, uname, upn=uname)
         # check the crealm and cname
         cname = enc_part['cname']
         self.assertEqual(NT_ENTERPRISE_PRINCIPAL, cname['name-type'])
@@ -775,7 +766,7 @@ class MS_Kile_Client_Principal_Lookup_Tests(KDCBaseTest):
             This test uses the altsecid, so the AS-REQ should fail.
         """
 
-        # Create user and machine accounts for the test.
+        # Create a user account for the test.
         #
         samdb = self.get_samdb()
         user_name = "mskileusr"
@@ -786,10 +777,6 @@ class MS_Kile_Client_Principal_Lookup_Tests(KDCBaseTest):
         self.add_attribute(samdb, dn, "altSecurityIdentities", alt_sec)
         ename = alt_name + "@" + realm
 
-        mach_name = "mskilemac"
-        (mc, _) = self.create_account(samdb, mach_name,
-                                      account_type=self.AccountType.COMPUTER)
-
         # Do the initial AS-REQ, should get a pre-authentication required
         # response
         etype = (AES256_CTS_HMAC_SHA1_96, ARCFOUR_HMAC_MD5)
