@@ -15,16 +15,14 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-import tarfile
 import os
 import shutil
 import tempfile
 from samba.tests import BlackboxTestCase, BlackboxProcessError
 from samba.netcmd import CommandError
 from samba.param import LoadParm
-from samba.join import join_DC
-from samba.credentials import Credentials
-from samba.logger import get_samba_logger
+from samba import safe_tarfile as tarfile
+
 
 # The backup tests require that a completely clean LoadParm object gets used
 # for the restore. Otherwise the same global LP gets re-used, and the LP
@@ -135,7 +133,7 @@ class DomainBackupOfflineCmp(BlackboxTestCase):
                         "localPolicyFlags", "operatingSystem", "displayName",
                         "dnsRecord", "dNSTombstoned",
                         "msDS-NC-Replica-Locations", "msDS-HasInstantiatedNCs",
-                        "interSiteTopologyGenerator"]
+                        "interSiteTopologyGenerator", "msKds-DomainID"]
         filter_arg = "--filter=" + ",".join(ignore_attrs)
         args = ["--two", filter_arg]
         self.ldapcmp(self.prov_dir, self.extract_dir, args)
@@ -151,7 +149,9 @@ class DomainBackupOfflineCmp(BlackboxTestCase):
 
         self.ldapcmp(self.prov_dir, self.extract_dir)
 
-    def ldapcmp(self, prov_dir, ex_dir, args=[]):
+    def ldapcmp(self, prov_dir, ex_dir, args=None):
+        if args is None:
+            args = []
         sam_fn = os.path.join("private", "sam.ldb")
         url1 = "tdb://" + os.path.join(os.path.realpath(prov_dir), sam_fn)
         url2 = "tdb://" + os.path.join(os.path.realpath(ex_dir), sam_fn)
