@@ -93,7 +93,7 @@ class TestSource(TestCase):
             if fname.endswith("python/samba/tests/krb5/kcrypto.py"):
                 # Imported from MIT testing repo
                 continue
-            if fname.endswith("python/samba/tests/krb5/rfc4120_pyasn1.py"):
+            if fname.endswith("python/samba/tests/krb5/rfc4120_pyasn1_generated.py"):
                 # Autogenerated
                 continue
             match = copyright_re.search(text)
@@ -114,7 +114,8 @@ class TestSource(TestCase):
         """Test that all .py files have a GPL disclaimer."""
         incorrect = []
 
-        gpl_txt = """
+        gpl_txts = [
+            """
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 3 of the License, or
@@ -127,8 +128,24 @@ class TestSource(TestCase):
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+""",
 """
-        gpl_re = re.compile(re.escape(gpl_txt), re.MULTILINE)
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+""",
+        ]
+        gpl_re = f'(?:{"|".join(map(re.escape, gpl_txts))})'
+        gpl_re = re.compile(gpl_re, re.MULTILINE)
 
         for fname, text in get_source_file_contents():
             if "wafsamba" in fname:
@@ -141,7 +158,7 @@ class TestSource(TestCase):
             if fname.endswith("python/samba/tests/krb5/kcrypto.py"):
                 # Imported from MIT testing repo
                 continue
-            if fname.endswith("python/samba/tests/krb5/rfc4120_pyasn1.py"):
+            if fname.endswith("python/samba/tests/krb5/rfc4120_pyasn1_generated.py"):
                 # Autogenerated
                 continue
             if not gpl_re.search(text):
@@ -149,7 +166,7 @@ class TestSource(TestCase):
 
         if incorrect:
             help_text = ['Some files have missing or incomplete GPL statement',
-                         gpl_txt]
+                         gpl_txts[-1]]
             for fname in incorrect:
                 help_text.append((' ' * 4) + fname)
 
